==> webpack-unused-find-1.0.6.tgz: package/index.js <==

const fs = require('fs')
const path = require('path')
const { deepListDirSync } = require('deep-list-dir')
const { processArgv } = require('./utils/getProcessArg')
const { useFileName } = require('./utils/getFileName')

//获取过滤条件方法
function getConditions (type) {
  let argv = processArgv()
  let list = []
  for (let i = 0; i < argv.length; i++) {
    if (argv[i].indexOf(type) != -1) {
      let arr = argv[i].split('=')
      list.push(arr[1])
    }
  }
  return list
}

//获取需要过滤的条件
function getRegular (v) {
  let conditions = getConditions('--exceed')
  for (let i = 0; i < conditions.length; i++) {
    if (v.indexOf(conditions[i]) != -1) {
      return true
    }
  }
  return false
}

function usedFind () {
  //扫描src文件下所有路径
  let allList = deepListDirSync(getConditions('--dir')[0], {})

//读取有用文件列表并存到集合里
  let pathSet = new Set()
  let file = fs.readFileSync(path.join(__dirname, `../../${useFileName}.txt`), 'utf8')
  file = file.split('\n')
  for (let i = 0; i < file.length; i++) {
    file[i] = file[i].replace(/\\/g, '/') //兼容window路径
    pathSet.add(file[i].substr(1))
  }

//获取无用的文件
  for (let i = 0; i < allList.length; i++) {
    allList[i] = allList[i].replace(/\\/g, '/') //兼容window路径
    if (!pathSet.has(allList[i]) && !getRegular(allList[i])) {
      //如果不在有用文件列表,又不符合过滤条件
      let argv = processArgv()
      if (argv.includes('--html')) {
        fs.appendFileSync(`unuse-list.html`, `<a href="${link}"></a>\n`, 'utf-8')
      } else {
        fs.appendFileSync(`unuse-list.txt`, `${link}\n`, 'utf-8')
      }
    }
  }
}

module.exports = { usedFind }

==> webpack-unused-find-1.0.8.tgz: package/index.js <==

const fs = require('fs')
const path = require('path')
const { deepListDirSync } = require('deep-list-dir')
const { processArgv } = require('./utils/getProcessArg')
const { useFileName } = require('./utils/getFileName')

//获取过滤条件方法
function getConditions (type) {
  let argv = processArgv()
  let list = []
  for (let i = 0; i < argv.length; i++) {
    if (argv[i].indexOf(type) != -1) {
      let arr = argv[i].split('=')
      list.push(arr[1])
    }
  }
  return list
}

//获取需要过滤的条件
function getRegular (v) {
  let conditions = getConditions('--exceed')
  for (let i = 0; i < conditions.length; i++) {
    if (v.indexOf(conditions[i]) != -1) {
      return true
    }
  }
  return false
}

function usedFind () {
  //扫描src文件下所有路径
  let allList = deepListDirSync(getConditions('--dir')[0], {})

//读取有用文件列表并存到集合里
  let pathSet = new Set()
  let file = fs.readFileSync(path.join(__dirname, `../../${useFileName}.txt`), 'utf8')
  file = file.split('\n')
  for (let i = 0; i < file.length; i++) {
    file[i] = file[i].replace(/\\/g, '/') //兼容window路径
    pathSet.add(file[i].substr(1))
  }

//获取无用的文件
  for (let i = 0; i < allList.length; i++) {
    allList[i] = allList[i].replace(/\\/g, '/') //兼容window路径
    if (!pathSet.has(allList[i]) && !getRegular(allList[i])) {
      //如果不在有用文件列表,又不符合过滤条件
      let argv = processArgv()
      if (argv.includes('--html')) {
        fs.appendFileSync(`unuse-list.html`, `<a href="${allList[i]}"></a>\n`, 'utf-8')
      } else {
        fs.appendFileSync(`unuse-list.txt`, `${allList[i]}\n`, 'utf-8')
      }
    }
  }
}

module.exports = { usedFind }
